//*****************************************************************************
//
// qtmixer - an X windows soundcard mixer program.
// Copyright (C) 1997 - 2000  Tom Daley
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The license is in the file COPYING.
//
// Tom Daley
// 1309 W. Lorraine Ave.
// Woodland Park, CO  80863-2329
//
// daley@codenet.net (Tom Daley)
// http://users.codenet.net/daley
//
//*****************************************************************************

#ifndef QTED_MIXER_H
#define QTED_MIXER_H

#include <qlist.h>
#include <qintdict.h>

#include "channel.h"
#include "stereo_slider.h"

//*****************************************************************************
//
//	After creating a mixer check valid().  
//	If not valid, call errorString() to find out why.
//	Also errors generate a signal you connect to a slot to handle errors.
//
//	errorString() will return an error string for you to do as you wish.
//
//*****************************************************************************

class QtedMixer : public QWidget {
   Q_OBJECT
   private:
      int _fd;
      int _valid;
      int _exclusive_record;
      int _channel_bits;
      int _record_bits;
      int _recordable_bits;
      int _stereo_bits;
      QString _error_str;
      QList <QtedMixerChannel> _channel_list;
      static const char *labels[];
      void error(QString function, QString error = "");
   public:
      QtedMixer(QIntDict<QString> titles, QString name = "/dev/mixer", 
		QWidget *parent = 0, const char *name = 0);
      int valid(void);		// is this a valid mixer
      QString errorString(void);
   protected:
      void resizeEvent(QResizeEvent *);
   private slots:
      void setValue(QtedMixerChannel *ch_p);
      void setRecord(QtedMixerChannel *ch_p);
   signals:
      void error(QString *);	// a signal is emited if an error is detected
};

#endif

//*****************************************************************************
